# G Square Conditional Independence Test

## Overview

This package contains conditional independence test functions using
the G-square test.

## Acknowledgement

The code fragments included in this package are logically copied and
pasted from [the pcalg package for R]
(http://cran.r-project.org/web/packages/pcalg/index.html) developed by
Markus Kalisch, Alain Hauser, Martin Maechler, Diego Colombo, Doris
Entner, Patrik Hoyer, Antti Hyttinen, and Jonas Peters.

## Code

The source code is available at https://github.com/keiichishima/gsq

## Bug Reports

Please submit bug reports or patches through the GitHub interface.

## Contributors

- Joost H. van der Linden, https://github.com/joosthvanderlinden
- Satoru Kobayashi, https://github.com/cpflat

## Author

Keiichi SHIMA
/ IIJ Innovation Institute Inc.
/ WIDE project
